@@ -1,11 +1,11 @@
 /*
-   Copyright (C) 2001, Sergey Poznyakoff.
-
    This file is part of GNU Radius SNMP Library.
+   Copyright (C) 2001,2007 Free Software Foundation, Inc.
+   Written by Sergey Poznyakoff
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License as
-   published by the Free Software Foundation; either version 2.1 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
