@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -25,31 +25,18 @@
 #endif
 #include <string.h>
 
-/*FIXME
-#ifndef HAVE_STRCHR
-# define strchr index
-# define strrchr rindex
-#endif
-#ifndef HAVE_MEMCPY
-# define memcpy(d, s, n) bcopy ((s), (d), (n))
-# define memmove(d, s, n) bcopy ((s), (d), (n))
-#endif
-*/
 #ifndef HAVE_BZERO
 # define bzero(s,n) memset(s, 0, n)
 #endif
 
-#if STDC_HEADERS
-# include <stdarg.h>
-# define __PVAR(c) c
-#else
-# include <varargs.h>
-# define __PVAR(c) 
-#endif
+#include <stdarg.h>
 
 #ifdef HAVE_SYS_TYPES_H
 # include <sys/types.h>
 #endif
+#ifdef HAVE_STDINT_H
+# include <stdint.h>
+#endif
 
 #ifdef HAVE_SYS_TIME_H
 # include <sys/time.h>
@@ -66,6 +53,17 @@
                       (tvp)->tv_sec == (uvp)->tv_sec &&\
                       (tvp)->tv_usec cmp (uvp)->tv_usec)
 #endif
+#ifndef timersub
+# define timersub(a, b, result)                             \
+  do {                                                      \
+    (result)->tv_sec = (a)->tv_sec - (b)->tv_sec;           \
+    (result)->tv_usec = (a)->tv_usec - (b)->tv_usec;        \
+    if ((result)->tv_usec < 0) {                            \
+      --(result)->tv_sec;                                   \
+      (result)->tv_usec += 1000000;                         \
+    }                                                       \
+  } while (0)
+#endif
 
 #if !HAVE_DECL_STRNCASECMP
 extern int strncasecmp(char*, char*, int);
@@ -80,7 +78,7 @@ extern struct tm *localtime_r(const time_t *timep, struct tm *res);
 #endif
 
 #if !HAVE_DECL_ASPRINTF
-int asprintf(/*char **result, const char *format, ...*/);
+int asprintf(char **result, const char *format, ...);
 #endif
 
 #if !HAVE_DECL_VASPRINTF
@@ -88,26 +86,13 @@ int vasprintf(char **result, const char *format, va_list args);
 #endif
 
 #if !HAVE_DECL_CRYPT
-extern char *crypt();
+extern char *crypt(const char *key, const char *salt);
 #endif
 
-#if defined(__alpha) && (defined(__osf__) || defined(__linux__))
-typedef unsigned int    UINT4;
-#else
-typedef unsigned long   UINT4;
-#endif
+typedef RETSIGTYPE (*grad_signal_handler_t)(int);
 
-typedef unsigned long counter;
-
-RETSIGTYPE (*install_signal(int signo, void (*func)(int)))(int);
-int set_nonblocking(int fd);
-int getmaxfd();
-UINT4 get_first_ip();
-
-typedef RETSIGTYPE (*signal_handler_t)(int);
-
-signal_handler_t rad_set_signal(int sig, signal_handler_t sighandler);
-void rad_reset_signal(int sig, signal_handler_t sighandler);
+grad_signal_handler_t grad_set_signal(int sig, grad_signal_handler_t sighandler);
+void grad_reset_signal(int sig, grad_signal_handler_t sighandler);
 
 
 #endif /* SYSDEP_H_INCLUDED */
