@@ -1,6 +1,6 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2007 Free Software Foundation, Inc.
+   2007,2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -33,7 +33,7 @@
 #include <radiusd.h>
 #include <rewrite.h>
 
-static int logging_category = L_CAT(L_MAIN);
+static int logging_category = GRAD_LOG_CAT(GRAD_LOG_MAIN);
 static grad_list_t /* of Channel*/ *chanlist;   /* List of defined channels */
 static char *log_prefix_hook;             /* Name of the global prefix hook */
 static char *log_suffix_hook;             /* Name of the global suffix hook */
@@ -135,7 +135,7 @@ log_get_category()
 static void
 log_set_category(int cat)
 {
-        logging_category = L_CAT(cat);
+        logging_category = GRAD_LOG_CAT(cat);
 }
 
 void
@@ -147,7 +147,7 @@ log_open(int cat)
 void
 log_close()
 {
-        log_set_category(L_MAIN);
+        log_set_category(GRAD_LOG_MAIN);
 }
 
 static char *catname[] = { /* category names */
@@ -247,7 +247,7 @@ log_to_channel(void *item, void *pdata)
         int spri;
         FILE *fp;
 
-	if (!(chan->pmask[data->cat] & L_MASK(data->pri)))
+	if (!(chan->pmask[data->cat] & GRAD_LOG_MASK(data->pri)))
 		return 0;
 	
         if (chan->options & LO_CAT) {
@@ -308,9 +308,10 @@ log_to_channel(void *item, void *pdata)
                 break;
                 
         case LM_SYSLOG:
-                spri = chan->id.prio;
-                if (chan->options & LO_PID)
-                        spri |= LOG_PID;
+                spri = chan->id.sl.prio;
+                openlog(chan->id.sl.tag ? chan->id.sl.tag : "radiusd",
+			(chan->options & LO_PID) ? LOG_PID : 0,
+			chan->id.sl.fac);
                 if (logbuf_printable_length(&pri_prefix)) {
 			if (data->errtext)
 				syslog(spri, "%s: %s%s%s: %s%s",
@@ -326,7 +327,7 @@ log_to_channel(void *item, void *pdata)
 				       SP(data->prefix),
 				       logbuf_ptr(&req_prefix),
 				       SP(data->text),
-				       logbuf_ptr(&req_suffix));
+ 				       logbuf_ptr(&req_suffix));
 		} else {
 			if (data->errtext)
 				syslog(spri, "%s%s%s: %s%s",
@@ -366,12 +367,12 @@ radiusd_logger(int level,
 	
         char *errstr = NULL;
 
-        cat = L_CAT(level);
+        cat = GRAD_LOG_CAT(level);
         if (cat == 0)
                 cat = log_get_category();
-        pri = L_PRI(level);
+        pri = GRAD_LOG_PRI(level);
         
-        if (loc) {
+        if (loc && loc->file) {
 		logbuf_append(&buf1, loc->file);
 		logbuf_append(&buf1, ":");
 		logbuf_append_line(&buf1, loc->line);
@@ -410,7 +411,7 @@ sqllog(int status, char *query)
         filename = status ? "sql-lost" : "sql.log";
         path = grad_mkfilename(grad_acct_dir, filename);
         if ((fp = fopen(path, "a")) == NULL) {
-                grad_log(L_ERR|L_PERROR,  
+                grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR,  
                          _("could not append to file %s"), path);
                 grad_free(path);
                 return;
@@ -429,6 +430,8 @@ channel_free(Channel *chan)
         grad_free(chan->name);
         if (chan->mode == LM_FILE)
                 grad_free(chan->id.file);
+	else
+		grad_free(chan->id.sl.tag); 
 	grad_free(chan->prefix_hook);
 	grad_free(chan->suffix_hook);
         grad_free(chan);
@@ -458,18 +461,18 @@ log_release(Channel *chan)
         }
 
         /* Make sure we have at least a channel for categories below
-           L_CRIT */
-        emerg = L_EMERG;
-        alert = L_ALERT;
-        crit  = L_CRIT;
+           GRAD_LOG_CRIT */
+        emerg = GRAD_LOG_EMERG;
+        alert = GRAD_LOG_ALERT;
+        crit  = GRAD_LOG_CRIT;
 	for (cp = grad_iterator_first(itr); cp; cp = grad_iterator_next(itr)) {
                 int i;
-                for (i = 1; i < L_NCAT; i++) {
-                        if (emerg && (cp->pmask[i] & L_MASK(emerg)))
+                for (i = 1; i < GRAD_LOG_NCAT; i++) {
+                        if (emerg && (cp->pmask[i] & GRAD_LOG_MASK(emerg)))
                                 emerg = 0;
-                        if (alert && (cp->pmask[i] & L_MASK(alert)))
+                        if (alert && (cp->pmask[i] & GRAD_LOG_MASK(alert)))
                                 alert = 0;
-                        if (crit && (cp->pmask[i] & L_MASK(crit)))
+                        if (crit && (cp->pmask[i] & GRAD_LOG_MASK(crit)))
                                 crit = 0;
                 }
         }
@@ -487,7 +490,7 @@ log_change_owner(RADIUS_USER *usr)
 	for (cp = grad_iterator_first(itr); cp; cp = grad_iterator_next(itr)) {
 		if (cp->mode == LM_FILE
 		    && chown(cp->id.file, usr->uid, usr->gid)) {
-			grad_log(L_ERR,
+			grad_log(GRAD_LOG_ERR,
 			         _("%s: cannot change owner to %d:%d"),
 			         cp->id.file, usr->uid, usr->gid);
 			errcnt++;
@@ -527,7 +530,7 @@ register_channel(Channel *chan)
                         /* check the accessibility of the file */
                         fp = fopen(filename, "a");
                         if (!fp) {
-                                grad_log(L_CRIT|L_PERROR,
+                                grad_log(GRAD_LOG_CRIT|GRAD_LOG_PERROR,
                                          _("can't access log file `%s'"),
                                          filename);
                                 grad_free(filename);
@@ -544,8 +547,12 @@ register_channel(Channel *chan)
         channel->mode = chan->mode;
         if (chan->mode == LM_FILE)
                 channel->id.file = filename;
-        else if (chan->mode == LM_SYSLOG)
-                channel->id.prio = chan->id.prio;
+        else if (chan->mode == LM_SYSLOG) {
+                channel->id.sl.prio = chan->id.sl.prio;
+		channel->id.sl.fac  = chan->id.sl.fac;
+		channel->id.sl.tag = chan->id.sl.tag ?
+			                grad_estrdup(chan->id.sl.tag) : NULL;
+	}
         channel->options = chan->options;
 	channel->prefix_hook = chan->prefix_hook;
 	channel->suffix_hook = chan->suffix_hook;
@@ -560,10 +567,10 @@ register_category0(int cat, int pri, Channel *chan)
 {
 	if (cat == -1) {
 		int i;
-		for (i = 0; i < L_NCAT; i++)
+		for (i = 0; i < GRAD_LOG_NCAT; i++)
 			chan->pmask[i] |= pri;
 	} else
-		chan->pmask[L_CAT(cat)] |= pri;
+		chan->pmask[GRAD_LOG_CAT(cat)] |= pri;
 }
 
 struct category_closure {
@@ -586,7 +593,7 @@ register_category(int cat, int pri, grad_list_t *clist)
 	struct category_closure clos;
 
         if (pri == -1)
-                pri = L_UPTO(L_DEBUG);
+                pri = GRAD_LOG_UPTO(GRAD_LOG_DEBUG);
 
 	clos.cat = cat;
 	clos.pri = pri;
@@ -686,23 +693,23 @@ static grad_keyword_t syslog_priority[] = {
 };
 
 static grad_keyword_t log_categories[] = {
-	{ "main",       L_MAIN },
-	{ "auth",       L_AUTH },
-	{ "acct",       L_ACCT },
-	{ "snmp",       L_SNMP },
-	{ "proxy",      L_PROXY },
+	{ "main",       GRAD_LOG_MAIN },
+	{ "auth",       GRAD_LOG_AUTH },
+	{ "acct",       GRAD_LOG_ACCT },
+	{ "snmp",       GRAD_LOG_SNMP },
+	{ "proxy",      GRAD_LOG_PROXY },
 	{ 0 }
 };
 
 static grad_keyword_t log_priorities[] = {
-	{ "emerg",      L_EMERG },
-	{ "alert",      L_ALERT },
-	{ "crit",       L_CRIT },
-	{ "err",        L_ERR },
-	{ "warning",    L_WARN },
-	{ "notice",     L_NOTICE },
-	{ "info",       L_INFO },
-	{ "debug",      L_DEBUG },
+	{ "emerg",      GRAD_LOG_EMERG },
+	{ "alert",      GRAD_LOG_ALERT },
+	{ "crit",       GRAD_LOG_CRIT },
+	{ "err",        GRAD_LOG_ERR },
+	{ "warning",    GRAD_LOG_WARN },
+	{ "notice",     GRAD_LOG_NOTICE },
+	{ "info",       GRAD_LOG_INFO },
+	{ "debug",      GRAD_LOG_DEBUG },
 	{ 0 }
 };
 
@@ -756,7 +763,7 @@ static int
 channel_stmt_end(void *block_data, void *handler_data)
 {
 	if (channel.mode == LM_UNKNOWN) {
-		grad_log(L_ERR,
+		grad_log(GRAD_LOG_ERR,
 		         _("%s:%d: no channel mode for `%s'"), 
 		         cfg_filename, cfg_line_num, channel.name);
 	} else 
@@ -777,11 +784,11 @@ get_priority(cfg_value_t *argv)
 
 	switch (argv[0].v.ch) {
 	case '!':
-		cat_def.pri = L_UPTO(L_DEBUG) & ~L_MASK(cat_def.pri);
+		cat_def.pri = GRAD_LOG_UPTO(GRAD_LOG_DEBUG) & ~GRAD_LOG_MASK(cat_def.pri);
 		break;
 
 	case '=':
-		cat_def.pri = L_MASK(cat_def.pri);
+		cat_def.pri = GRAD_LOG_MASK(cat_def.pri);
 		break;
 
 	default:
@@ -817,7 +824,7 @@ category_stmt_handler(int argc, cfg_value_t *argv,
 								-1);
 				if (cat_def.pri == -1)
 					return 1;
-				cat_def.pri = L_UPTO(cat_def.pri);
+				cat_def.pri = GRAD_LOG_UPTO(cat_def.pri);
 			}
 		}
 		break;
@@ -863,7 +870,7 @@ category_stmt_handler(int argc, cfg_value_t *argv,
 							argv[3].v.string, -1);
 			if (cat_def.pri == -1) 
 				return 1;
-			cat_def.pri = L_UPTO(cat_def.pri);
+			cat_def.pri = GRAD_LOG_UPTO(cat_def.pri);
 			break;
 
 		default:
@@ -912,12 +919,12 @@ category_stmt_end(void *block_data, void *handler_data)
 {
 	if (cat_def.init) {
 		switch (cat_def.cat) {
-		case L_AUTH:
+		case GRAD_LOG_AUTH:
 			log_mode = cat_def.level;
 			break;
 		default:
 			if (cat_def.level)
-				grad_log(L_WARN,
+				grad_log(GRAD_LOG_WARN,
 				         "%s:%d: %s",
 				         cfg_filename, cfg_line_num,
 				_("no levels applicable for this category"));
@@ -945,7 +952,7 @@ category_set_channel(int argc, cfg_value_t *argv,
 	channel = channel_lookup(argv[1].v.string);
 
 	if (!channel) {
-		grad_log(L_ERR,
+		grad_log(GRAD_LOG_ERR,
 		         _("%s:%d: channel `%s' not defined"),
 		         cfg_filename, cfg_line_num, argv[1].v.string);
 	} else {
@@ -989,7 +996,7 @@ category_set_level(int argc, cfg_value_t *argv,
 		int level;
 		
 		if (argv[i].type != CFG_STRING) {
-			grad_log(L_ERR,
+			grad_log(GRAD_LOG_ERR,
 			         _("%s:%d: list item %d has wrong datatype"),
 			         cfg_filename, cfg_line_num,
 			         i);
@@ -1005,7 +1012,7 @@ category_set_level(int argc, cfg_value_t *argv,
 			level = argv[i++].v.number;
 		}
 		if (grad_set_module_debug_level(modname, level)) {
-			grad_log(L_WARN,
+			grad_log(GRAD_LOG_WARN,
 			         _("%s:%d: no such module name: %s"),
 			         cfg_filename, cfg_line_num, modname);
 		}
@@ -1037,7 +1044,7 @@ channel_syslog_handler(int argc, cfg_value_t *argv, void *block_data,
 	int facility;
 	int prio;
 	
-	if (argc != 4) {
+	if (argc < 4 || argc > 5) {
 		cfg_argc_error(argc < 4);
 		return 0;
 	}
@@ -1079,8 +1086,17 @@ channel_syslog_handler(int argc, cfg_value_t *argv, void *block_data,
 	if (prio == -1)
 		return 1;
 	
+	if (argc == 5) {
+		if (argv[4].type != CFG_STRING) {
+			cfg_type_error(CFG_STRING);
+			return 0;
+		}
+		channel.id.sl.tag = argv[4].v.string;
+	} else
+		channel.id.sl.tag = NULL;
 	channel.mode = LM_SYSLOG;
-	channel.id.prio = facility | prio ;
+	channel.id.sl.prio = prio;
+	channel.id.sl.fac = facility;
 	return 0;
 }
 
