@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2003,2004,2006,2007 Free Software Foundation, Inc.
+   Copyright (C) 2003,2004,2006,2007,2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -50,24 +50,6 @@ typedef struct {
 
 /* Low-level calls */
 
-/* Recompute the timeout TVAL taking into account the time elapsed since
-   START */
-static int
-recompute_timeout(struct timeval *start, struct timeval *tval)
-{
-	struct timeval now, diff;
-	
-	gettimeofday(&now, NULL);
-	timersub(&now, start, &diff);
-	if (timercmp(&diff, tval, <)) {
-		struct timeval tmp;
-		timersub(tval, &diff, &tmp);
-		*tval = tmp;
-		return 0;
-	} 
-	return 1;
-}
-
 /* Write into the pipe (represented by FD) SIZE bytes from PTR. TV
    sets timeout. TV==NULL means no timeout is imposed.
 
@@ -92,7 +74,7 @@ pipe_write(int fd, void *ptr, size_t size, struct timeval *tv)
 			FD_SET(fd, &wr_set);
 
 			tval = *tv;
-			if (recompute_timeout (&start, &tval)) {
+			if (grad_recompute_timeout (&start, &tval)) {
 				errno = ETIMEDOUT;
 				break;
 			}
@@ -159,7 +141,7 @@ pipe_read(int fd, void *ptr, size_t size, struct timeval *tv)
 			FD_SET(fd, &rd_set);
 
 			tval = *tv;
-			if (recompute_timeout (&start, &tval)) {
+			if (grad_recompute_timeout (&start, &tval)) {
 				errno = ETIMEDOUT;
 				break;
 			}
@@ -242,18 +224,18 @@ rpp_start_process(rpp_proc_t *proc, int (*proc_main)(void *), void *data)
 	pid_t pid;
 	
 	if (pipe(inp)) {
-		grad_log(L_ERR, "pipe(inp): %s", strerror(errno));
+		grad_log(GRAD_LOG_ERR, "pipe(inp): %s", strerror(errno));
 		return -1;
 	}
 	
 	if (pipe(outp)) {
-		grad_log (L_ERR, "pipe(outp): %s", strerror(errno));
+		grad_log (GRAD_LOG_ERR, "pipe(outp): %s", strerror(errno));
 		return -1;
 	}
 
 	pid = fork();
 	if (pid == -1) {
-		grad_log (L_ERR, "fork: %s", strerror(errno));
+		grad_log (GRAD_LOG_ERR, "fork: %s", strerror(errno));
 		return -1;
 	}
 	if (pid == 0) {
@@ -370,7 +352,7 @@ rpp_remove(rpp_proc_t *p)
 {
 	char buffer[128];
 	format_exit_status(buffer, sizeof buffer, p->exit_status);
-	grad_log(L_NOTICE, _("child %lu %s"),
+	grad_log(GRAD_LOG_NOTICE, _("child %lu %s"),
 		 (unsigned long) p->pid, buffer);
 	_rpp_remove(p);
 }
@@ -513,7 +495,7 @@ rpp_check_pid(pid_t pid)
 static void
 _rpp_slay(rpp_proc_t *p, char *msg)
 {
-	grad_log(L_NOTICE, _("Killing process %lu: %s"), 
+	grad_log(GRAD_LOG_NOTICE, _("Killing process %lu: %s"), 
                  (u_long) p->pid, msg);
 	kill(p->pid, SIGKILL);
 	_rpp_remove(p);
@@ -615,7 +597,7 @@ sig_handler(int sig)
 		break;
 		
 	case SIGALRM:
-		grad_log(L_INFO, _("Child exiting on timeout."));
+		grad_log(GRAD_LOG_INFO, _("Child exiting on timeout."));
 		/*FALLTHRU*/
 		
 	case SIGTERM:
@@ -650,9 +632,6 @@ rpp_request_handler(void *arg ARG_UNUSED)
 	radiusd_signal_init(sig_handler);
 	grad_set_signal(SIGALRM, sig_handler);
 	request_init_queue();
-#ifdef USE_SERVER_GUILE
-        scheme_redirect_output();
-#endif
 	
 	while (1) {
 		int rc;
@@ -664,7 +643,7 @@ rpp_request_handler(void *arg ARG_UNUSED)
 		if (len != sizeof frq) {
 			if (errno == EINTR)
 				continue;
-			grad_log(L_ERR,
+			grad_log(GRAD_LOG_ERR,
 			         _("Child received malformed header (len = %d, error = %s)"),
 			         len, strerror(errno));
 			radiusd_exit0();
@@ -676,7 +655,7 @@ rpp_request_handler(void *arg ARG_UNUSED)
 		}
 		
 		if (rpp_fd_read(rpp_stdin, data, frq.size, NULL) != frq.size) {
-			grad_log(L_ERR,
+			grad_log(GRAD_LOG_ERR,
 			         _("Child received malformed data"));
 			radiusd_exit0();
 		}
