@@ -1,11 +1,12 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2005,
+   2006,2007,2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
    
    GNU Radius is distributed in the hope that it will be useful,
@@ -17,8 +18,6 @@
    along with GNU Radius; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#define RADIUS_MODULE_STAT_C
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -37,10 +36,8 @@
 #include <ctype.h>
 #include <netinet/in.h>
 #include <fcntl.h>
-#include <sysdep.h>
+
 #include <radiusd.h>
-#include <radutmp.h>
-#include <radpaths.h>
 
 #ifdef USE_SNMP
 
@@ -64,30 +61,30 @@ shmem_alloc(size_t size)
 	int init = 0;
 
 	if (tempfd == -1) {
-		tempfd = open(radstat_path, O_RDWR);
+		tempfd = open(grad_stat_file, O_RDWR);
 		if (tempfd == -1) {
 			if (errno == ENOENT) 
-				tempfd = open(radstat_path,
+				tempfd = open(grad_stat_file,
 					      O_RDWR|O_CREAT|O_TRUNC,
 					      statfile_perms);
 			
 			if (tempfd == -1) {
-				radlog(L_ERR|L_PERROR, 
-					_("can't open file `%s'"),
-				        radstat_path);
+				grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR, 
+					 _("can't open file `%s'"),
+				         grad_stat_file);
 				return -1;
 			}
 		}
 		if (fstat(tempfd, &sb)) {
-			radlog(L_ERR|L_PERROR, _("can't stat `%s'"),
-			       radstat_path);
+			grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR, _("can't stat `%s'"),
+			         grad_stat_file);
 			close(tempfd);
 			return -1;
 		}
 		if ((sb.st_mode & statfile_perms) != statfile_perms) {
-			radlog(L_ERR,
-			       _("SNMP system disabled: file `%s' has incorrect permissions"),
-			       radstat_path);
+			grad_log(GRAD_LOG_ERR,
+			         _("SNMP system disabled: file `%s' has incorrect permissions"),
+			       grad_stat_file);
 			close(tempfd);
 			return -1;
 		}
@@ -105,12 +102,12 @@ shmem_alloc(size_t size)
 			  tempfd, 0);
 	
 	if (shmem_base == MAP_FAILED) {
-		radlog(L_ERR|L_PERROR, _("mmap failed"));
+		grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR, _("mmap failed"));
 		return -1;
 	} else {
 		shmem_size = size;
 		if (init) 
-			bzero(shmem_base, size);
+			memset(shmem_base, 0, size);
 	}
 	return 0;
 }
@@ -120,6 +117,8 @@ shmem_free()
 {
 	munmap(shmem_base, shmem_size);
 	close(tempfd);
+	tempfd = -1;
+	offset = 0;
 }
 
 void *
@@ -130,16 +129,16 @@ shmem_get(size_t size, int zero)
 	if (!shmem_base && shmem_alloc(size))
 		return NULL;
 	if (shmem_size - offset < size) {
-		radlog(L_ERR,
-		       ngettext("shmem_get(): can't allocate %d byte",
-				"shmem_get(): can't allocate %d bytes",
-				size),
-		       size);
+		grad_log(GRAD_LOG_ERR,
+		         ngettext("shmem_get(): can't allocate %d byte",
+			  	  "shmem_get(): can't allocate %d bytes",
+				  size),
+		         size);
 	} else {
 		ptr = shmem_base + offset;
 		offset += size;
 		if (zero)
-			bzero(ptr, size);
+			memset(ptr, 0, size);
 	}
 	return ptr;
 }
@@ -167,7 +166,7 @@ stat_init()
 	if (shmem_alloc(stat_port_count * sizeof(PORT_STAT) +
 			sizeof(*server_stat) +
 			stat_nas_count * sizeof(struct nas_stat))) {
-		radlog(L_NOTICE, _("stat_init failed"));
+		grad_log(GRAD_LOG_NOTICE, _("stat_init failed"));
 		return;
 	}
 
@@ -191,8 +190,10 @@ stat_init()
 void
 stat_done()
 {
-	if (server_stat) 
+	if (server_stat) {
 		shmem_free();
+		server_stat = NULL;
+	}
 }
 
 #define FOR_EACH_PORT(p) \
@@ -211,7 +212,7 @@ stat_alloc_port()
 }
 
 PORT_STAT *
-stat_find_port(NAS *nas, int port_no)
+stat_find_port(grad_nas_t *nas, int port_no)
 {
 	PORT_STAT *port;
 
@@ -220,27 +221,27 @@ stat_find_port(NAS *nas, int port_no)
 	FOR_EACH_PORT(port) {
 		if (port->ip == 0)
 			break;
-		if (ip_addr_in_net_p(&nas->netdef, port->ip)
+		if (grad_ip_in_net_p(&nas->netdef, port->ip)
 		    && port->port_no == port_no)
 			return port;
 	}
 
 	/* Port not found */
 	if ((port = stat_alloc_port()) == NULL) {
-		radlog(L_WARN,
-		       _("reached SNMP storage limit for the number of monitored ports: increase max-port-count"));
+		grad_log(GRAD_LOG_WARN,
+		         _("reached SNMP storage limit for the number of monitored ports: increase max-port-count"));
 		return NULL;
 	}
 	port->ip = nas->netdef.ipaddr;
 	port->port_no = port_no;
 	
-	debug(1, ("next offset %d", port - port_stat));
+	GRAD_DEBUG1(1, "next offset %d", port - port_stat);
 
 	return port;
 }
 
 int
-stat_get_port_index(NAS *nas, int port_no)
+stat_get_port_index(grad_nas_t *nas, int port_no)
 {
 	PORT_STAT *port;
 	
@@ -249,7 +250,7 @@ stat_get_port_index(NAS *nas, int port_no)
 	FOR_EACH_PORT(port) {
 		if (port->ip == 0)
 			break;
-		if (ip_addr_in_net_p(&nas->netdef, port->ip)
+		if (grad_ip_in_net_p(&nas->netdef, port->ip)
 		    && port->port_no == port_no)
 			return port - port_stat + 1;
 	}
@@ -257,7 +258,7 @@ stat_get_port_index(NAS *nas, int port_no)
 }
 
 int
-stat_get_next_port_no(NAS *nas, int port_no)
+stat_get_next_port_no(grad_nas_t *nas, int port_no)
 {
 	PORT_STAT *port;
 	int next = stat_port_count;
@@ -267,7 +268,7 @@ stat_get_next_port_no(NAS *nas, int port_no)
 	FOR_EACH_PORT(port) {
 		if (port->ip == 0)
 			break;
-		if (ip_addr_in_net_p(&nas->netdef, port->ip)
+		if (grad_ip_in_net_p(&nas->netdef, port->ip)
 		    && port->port_no > port_no 
 		    && port->port_no < next)
 			next = port->port_no;
@@ -278,19 +279,19 @@ stat_get_next_port_no(NAS *nas, int port_no)
 void
 stat_update(struct radutmp *ut, int status)
 {
-	NAS *nas;
+	grad_nas_t *nas;
 	PORT_STAT *port;
 	long dt;
-        char ipbuf[DOTTED_QUAD_LEN];
+        char ipbuf[GRAD_IPV4_STRING_LENGTH];
 	
 	if (!server_stat)
 		return;
-	nas = nas_lookup_ip(ntohl(ut->nas_address));
+	nas = grad_nas_lookup_ip(ntohl(ut->nas_address));
 	if (!nas) {
-		radlog(L_WARN,
-		       _("stat_update(): portno %d: can't find nas for IP %s"),
-		       ut->nas_port,
-		       ip_iptostr(ntohl(ut->nas_address), ipbuf));
+		grad_log(GRAD_LOG_WARN,
+		         _("stat_update(): portno %d: can't find nas for IP %s"),
+		         ut->nas_port,
+		         grad_ip_iptostr(ntohl(ut->nas_address), ipbuf));
 		return;
 	}
 	if (nas->netdef.ipaddr == 0) /* DEFAULT nas */
@@ -298,10 +299,10 @@ stat_update(struct radutmp *ut, int status)
 	
 	port = stat_find_port(nas, ut->nas_port);
 	if (!port) {
-		radlog(L_WARN,
-		       _("stat_update(): port %d not found on NAS %s"),
-		       ut->nas_port,
-		       ip_iptostr(ntohl(ut->nas_address), ipbuf));
+		grad_log(GRAD_LOG_WARN,
+		         _("stat_update(): port %d not found on NAS %s"),
+		         ut->nas_port,
+		         grad_ip_iptostr(ntohl(ut->nas_address), ipbuf));
 		return;
 	}
 
@@ -310,10 +311,10 @@ stat_update(struct radutmp *ut, int status)
 		if (port->start) {
 			dt = ut->time - port->start;
 			if (dt < 0) {
-                                radlog(L_NOTICE,
-				       "stat_update(START,%s,%s,%d): %s",
-				       ut->login, nas->shortname, ut->nas_port,
-				       _("negative port idle time"));
+                                grad_log(GRAD_LOG_NOTICE,
+				         "stat_update(START,%s,%s,%d): %s",
+				         ut->login, nas->shortname, ut->nas_port,
+				         _("negative port idle time"));
 			} else {
 				port->idle += dt;
 			}
@@ -334,7 +335,7 @@ stat_update(struct radutmp *ut, int status)
 		if (port->start) {
 			dt = ut->time - port->start;
 			if (dt < 0) {
-                                radlog(L_NOTICE,
+                                grad_log(GRAD_LOG_NOTICE,
 				       "stat_update(STOP,%s,%s,%d): %s",
 				       ut->login, nas->shortname, ut->nas_port,
 				       _("negative port session time"));
@@ -358,27 +359,30 @@ stat_update(struct radutmp *ut, int status)
 		break;
 	}
 
-	debug(1,
-		("NAS %#x port %d: act %d, cnt %d, start %d, inuse %d/%d idle %d/%d",
-		 port->ip, port->port_no, port->active,
-		 port->count, port->start,
-		 port->inuse, port->maxinuse.time,
-		 port->idle, port->maxidle.time));
+	GRAD_DEBUG9(1,
+		"NAS %#x port %d: act %d, cnt %d, start %d, inuse %d/%d idle %d/%d",
+		port->ip, port->port_no, port->active,
+		port->count, port->start,
+		port->inuse, port->maxinuse.time,
+		port->idle, port->maxidle.time);
 }
 
 void
 stat_count_ports()
 {
-	NAS *nas;
+	grad_nas_t *nas;
 	struct nas_stat *statp;
 	PORT_STAT *port;
-	
+	grad_iterator_t *itr;
+
 	if (!server_stat)
 		return;
-	for (nas = nas_next(NULL); nas; nas = nas_next(nas)) {
+ 	itr = grad_nas_iterator();	
+	for (nas = grad_iterator_first(itr); nas; nas = grad_iterator_next(itr)) {
 		statp = nas->app_data;
 		statp->ports_active = statp->ports_idle = 0;
 	}
+	grad_iterator_destroy(&itr);
 	
 	radstat.port_active_count = radstat.port_idle_count = 0;
 
@@ -386,7 +390,7 @@ stat_count_ports()
 		if (port->ip == 0)
 			break;
 
-		nas = nas_lookup_ip(port->ip);
+		nas = grad_nas_lookup_ip(port->ip);
 		if (!nas) {
 			/* Silently ignore */
 			continue;
@@ -441,7 +445,7 @@ snmp_init_nas_stat()
 /* For a given ip_address return NAS statistics info associated with it.
    if no NAS with this address is known, return NULL */
 struct nas_stat *
-find_nas_stat(UINT4 ip_addr)
+find_nas_stat(grad_uint32_t ip_addr)
 {
         struct nas_stat *np;
 
@@ -456,7 +460,7 @@ find_nas_stat(UINT4 ip_addr)
 
 /* Attach NAS stat info to a given NAS structure. */
 void
-snmp_attach_nas_stat(NAS *nas)
+snmp_attach_nas_stat(grad_nas_t *nas)
 {
         struct nas_stat *np;
 
@@ -465,8 +469,8 @@ snmp_attach_nas_stat(NAS *nas)
         np = find_nas_stat(nas->netdef.ipaddr); 
         if (!np) {
 		if (server_stat->nas_index >= server_stat->nas_count) {
-			radlog(L_WARN,
-			       _("reached SNMP storage limit for the number of monitored NASes: increase max-nas-count"));
+			grad_log(GRAD_LOG_WARN,
+			         _("reached SNMP storage limit for the number of monitored NASes: increase max-nas-count"));
 			return;
 		}
 		np = nas_stat + server_stat->nas_index;
@@ -516,11 +520,11 @@ stat_cfg_file(int argc, cfg_value_t *argv,
 		return 0;
 	}
 
-	efree(radstat_path);
+	grad_free(grad_stat_file);
 	if (argv[1].v.string[0] != '/')
-		radstat_path = estrdup(argv[1].v.string);
+		grad_stat_file = grad_estrdup(argv[1].v.string);
 	else
-		radstat_path = mkfilename(radlog_dir, argv[1].v.string); 
+		grad_stat_file = grad_mkfilename(grad_log_dir, argv[1].v.string); 
 	
 	return 0;
 }
