@@ -1,11 +1,12 @@
 /*
-   Copyright (C) 2001,2003, Sergey Poznyakoff.
-
    This file is part of GNU Radius SNMP Library.
+   Copyright (C) 2001,2003,2004,2007 Free Software Foundation, Inc.
+
+   Written by Sergey Poznyakoff
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License as
-   published by the Free Software Foundation; either version 2.1 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
@@ -22,9 +23,9 @@
 # include <config.h>
 #endif
 
-#include <asn1.h>
-#include <snmp.h>
-#include <snmp_intern.h>
+#include <snmp/asn1.h>
+#include <snmp/snmp.h>
+#include <snmp/snmp_intern.h>
 #include <stdlib.h>
 #include <string.h>
 
